@@ -1,16 +1,16 @@
 ## File Name: tampv2datalist.R
-## File Version: 9.06
+## File Version: 9.07
 
 
 ##################################################################
 tampv2datalist <- function( tam.pv.object , pvnames = NULL , Y = NULL ,
-			Y.pid = "pid" , as_mids = FALSE)
+			Y.pid = "pid" , as_mids = FALSE, stringsAsFactors = FALSE )
 {
 	pv <- tam.pv.object$pv
 	ndim <- tam.pv.object$ndim
 	nplausible <- tam.pv.object$nplausible
 	Y00 <- data.frame( "pid" = tam.pv.object$pid , "pweights" = tam.pv.object$pweights,
-				stringsAsFactors = FALSE )
+				stringsAsFactors = stringsAsFactors )
 	if ( ! is.null(Y) ){ 
 		Y <- as.data.frame(Y)
 		if(  sum( colnames(Y) %in% Y.pid ) == 0 ){
